@@ -37,7 +37,7 @@ AbstractImportExportJob::AbstractImportExportJob(QObject *parent, ArchiveStorage
     , mImportExportProgressIndicator(new ImportExportProgressIndicatorBase(this))
 {
     mImportExportProgressIndicator->setNumberOfStep(numberOfStep);
-    connect(mImportExportProgressIndicator, &ImportExportProgressIndicatorBase::info, this, &AbstractImportExportJob::info);
+    connect(mImportExportProgressIndicator, &ImportExportProgressIndicatorBase::info, this, &AbstractImportExportJob::emitInfo);
 }
 
 AbstractImportExportJob::~AbstractImportExportJob()
@@ -114,7 +114,7 @@ void AbstractImportExportJob::backupFile(const QString &filename, const QString
     if (QFileInfo::exists(filename)) {
         const bool fileAdded = archive()->addLocalFile(filename, path + storedName);
         if (fileAdded) {
-            Q_EMIT info(i18n("\"%1\" backup done.", path + storedName));
+            emitInfo(i18n("\"%1\" backup done.", path + storedName));
         } else {
             Q_EMIT error(i18n("\"%1\" cannot be exported.", path + storedName));
         }
@@ -255,8 +255,8 @@ void AbstractImportExportJob::initializeImportJob()
         mTempDir = new QTemporaryDir();
         mTempDirName = mTempDir->path();
         mCreateResource = new PimCommon::CreateResource();
-        connect(mCreateResource, &PimCommon::CreateResource::createResourceInfo, this, &AbstractImportExportJob::info);
-        connect(mCreateResource, &PimCommon::CreateResource::createResourceError, this, &AbstractImportExportJob::error);
+        connect(mCreateResource, &PimCommon::CreateResource::createResourceInfo, this, &AbstractImportExportJob::emitInfo);
+        connect(mCreateResource, &PimCommon::CreateResource::createResourceError, this, &AbstractImportExportJob::emitError);
     }
 }
 
@@ -266,11 +266,12 @@ void AbstractImportExportJob::copyToDirectory(const KArchiveEntry *entry, const
     if (!subfolderDir->copyTo(dest)) {
         qCDebug(PIMDATAEXPORTERCORE_LOG) << "directory cannot copy to " << dest;
     }
-    Q_EMIT info(i18n("\"%1\" was copied.", dest));
+    emitInfo(i18n("\"%1\" was copied.", dest));
 }
 
 void AbstractImportExportJob::copyToFile(const KArchiveFile *archivefile, const QString &dest, const QString &filename, const QString &prefix)
 {
+    emitInfo(i18n("Restoring \"%1\"...", filename));
     QDir dir(mTempDirName);
     const QString copyToDirName(mTempDirName + QLatin1Char('/') + prefix);
     const bool created = dir.mkpath(copyToDirName);
@@ -297,7 +298,7 @@ void AbstractImportExportJob::copyToFile(const KArchiveFile *archivefile, const
     if (!file.copy(dest)) {
         mImportExportProgressIndicator->showErrorMessage(i18n("File \"%1\" cannot be copied to \"%2\".", filename, dest), i18n("Copy file"));
     } else {
-        Q_EMIT info(i18n("\"%1\" was restored.", filename));
+        emitInfo(i18n("\"%1\" was restored.", filename));
     }
 }
 
@@ -307,8 +308,8 @@ void AbstractImportExportJob::backupResourceFile(const QString &identifier, cons
     job->setDefaultPath(defaultPath);
     job->setIdentifier(identifier);
     job->setZip(archive());
-    connect(job, &BackupResourceFileJobImpl::error, this, &AbstractImportExportJob::error);
-    connect(job, &BackupResourceFileJobImpl::info, this, &AbstractImportExportJob::info);
+    connect(job, &BackupResourceFileJobImpl::error, this, &AbstractImportExportJob::emitError);
+    connect(job, &BackupResourceFileJobImpl::info, this, &AbstractImportExportJob::emitInfo);
     job->start();
 }
 
@@ -349,14 +350,18 @@ AbstractImportExportJob::restoreResourceFile(const QString &resourceBaseName, co
                     const KArchiveEntry *dataResouceEntry = mArchiveDirectory->entry(dataFile);
                     if (dataResouceEntry && dataResouceEntry->isFile()) {
                         const auto file = static_cast<const KArchiveFile *>(dataResouceEntry);
-                        if (!file->copyTo(newUrl)) {
+                        if (!file->copyTo(QFileInfo(newUrl).path())) {
                             qCWarning(PIMDATAEXPORTERCORE_LOG) << "AbstractImportExportJob: file " << dataFile << " can not copy to " << newUrl;
                         }
                     }
-                    if (!newUrl.isEmpty()) {
-                        settings.insert(QStringLiteral("Path"), newUrl);
+                    // setPath doesn't exist in groupware
+                    if (resourceBaseName != QStringLiteral("akonadi_davgroupware_resource")
+                        && resourceBaseName != QStringLiteral("akonadi_openxchange_resource")
+                        && resourceBaseName != QStringLiteral("akonadi_google_resource")) {
+                        if (!newUrl.isEmpty()) {
+                            settings.insert(QStringLiteral("Path"), newUrl);
+                        }
                     }
-
                     const QString agentConfigFile = value.akonadiAgentConfigFile;
                     if (!agentConfigFile.isEmpty()) {
                         const KArchiveEntry *akonadiAgentConfigEntry = mArchiveDirectory->entry(agentConfigFile);
@@ -378,7 +383,7 @@ AbstractImportExportJob::restoreResourceFile(const QString &resourceBaseName, co
                 }
             }
         }
-        Q_EMIT info(i18n("Resources restored."));
+        emitInfo(i18n("Resources restored."));
     } else {
         Q_EMIT error(i18n("No resources files found."));
         qDebug() << " resourceBaseName " << resourceBaseName;
@@ -422,10 +427,14 @@ void AbstractImportExportJob::extractZipFile(const KArchiveFile *file, const QSt
                 if (entry) {
                     if (entry->isDirectory()) {
                         const auto dir = static_cast<const KArchiveDirectory *>(entry);
-                        dir->copyTo(destination + QLatin1Char('/') + dir->name(), true);
+                        if (!dir->copyTo(destination + QLatin1Char('/') + dir->name(), true)) {
+                            qCWarning(PIMDATAEXPORTERCORE_LOG) << " Error to copy directory" << destination + QLatin1Char('/') + dir->name();
+                        }
                     } else if (entry->isFile()) {
                         const auto dir = static_cast<const KArchiveFile *>(entry);
-                        dir->copyTo(destination);
+                        if (!dir->copyTo(destination)) {
+                            qCWarning(PIMDATAEXPORTERCORE_LOG) << " Error to copy file" << destination;
+                        }
                     }
                 }
                 qApp->processEvents();
@@ -478,7 +487,7 @@ void AbstractImportExportJob::restoreConfigFile(const QString &configNameStr)
 
 void AbstractImportExportJob::infoAboutNewResource(const QString &resourceName)
 {
-    Q_EMIT info(i18n("Resource \'%1\' created.", resourceName));
+    emitInfo(i18n("Resource \'%1\' created.", resourceName));
 }
 
 int AbstractImportExportJob::archiveVersion()
@@ -493,18 +502,18 @@ void AbstractImportExportJob::setArchiveVersion(int version)
 
 void AbstractImportExportJob::slotSynchronizeInstanceFailed(const QString &instance)
 {
-    Q_EMIT error(i18n("Failed to synchronize %1.", instance));
+    Q_EMIT error(i18n("Failed to synchronize \'%1\'.", instance));
 }
 
 void AbstractImportExportJob::slotSynchronizeInstanceDone(const QString &name, const QString &identifier)
 {
-    Q_EMIT info(i18n("Resource %1 synchronized.", name));
+    emitInfo(i18n("Resource \'%1\' synchronized.", name));
     Q_EMIT needSynchronizeResource(name, identifier);
 }
 
 void AbstractImportExportJob::slotAllResourceSynchronized()
 {
-    Q_EMIT info(i18n("All resources synchronized."));
+    emitInfo(i18n("All resources synchronized."));
     slotNextStep();
 }
 
@@ -513,9 +522,24 @@ void AbstractImportExportJob::slotNextStep()
     // Implement in sub class.
 }
 
+QString AbstractImportExportJob::generateInfo(const QString &info)
+{
+    return applicationName() + QLatin1Char(' ') + info;
+}
+
+void AbstractImportExportJob::emitInfo(const QString &str)
+{
+    Q_EMIT info(generateInfo(str));
+}
+
+void AbstractImportExportJob::emitError(const QString &str)
+{
+    Q_EMIT error(generateInfo(str));
+}
+
 void AbstractImportExportJob::startSynchronizeResources(const QStringList &listResourceToSync)
 {
-    Q_EMIT info(i18n("Start synchronizing..."));
+    emitInfo(i18n("Start synchronizing..."));
     auto job = new SynchronizeResourceJob(this);
     job->setListResources(listResourceToSync);
     connect(job, &SynchronizeResourceJob::synchronizationFinished, this, &AbstractImportExportJob::slotAllResourceSynchronized);
@@ -552,7 +576,7 @@ void AbstractImportExportJob::storeDirectory(const QString &subDirectory)
     if (directoryToStore.exists()) {
         const bool templateDirAdded = archive()->addLocalDirectory(directoryToStore.path(), Utils::dataPath() + subDirectory);
         if (templateDirAdded) {
-            Q_EMIT info(i18n("Directory \"%1\" added to backup file.", directoryToStore.path()));
+            emitInfo(i18n("Directory \"%1\" added to backup file.", directoryToStore.path()));
         } else {
             Q_EMIT error(i18n("Directory \"%1\" cannot be added to backup file.", directoryToStore.path()));
         }
